@@ -16,11 +16,9 @@ impl<'a> Navigation<'a> {
 
     /// Builds a navigation tree given a root directory
     pub fn build_for(&self, dir: &Directory) -> Vec<Link> {
-        let default: Vec<Link> = dir.links();
-
         match &self.config.navigation() {
-            None => default,
-            Some(nav) => self.customize(nav, &default),
+            None => dir.links(false),
+            Some(nav) => self.customize(nav, &dir.links(true)),
         }
     }
 
@@ -40,7 +38,20 @@ impl<'a> Navigation<'a> {
     fn customize(&self, rules: &[NavRule], default: &[Link]) -> Vec<Link> {
         let mut links = vec![];
 
+        let root_path_rule = NavRule::File(PathBuf::from("/"));
+
         for rule in rules {
+            let rule = if rule
+                .is_default_readme_rule(&self.config.project_root(), &self.config.docs_dir())
+            {
+                // If we're building navigation for the default readme file, we should
+                // use a different path as the rule will contain "/README.md", while the
+                // rest of the program expects it to be "/"
+                &root_path_rule
+            } else {
+                rule
+            };
+
             match rule {
                 NavRule::File(path) => links.push(
                     self.find_matching_link(path, &default)
@@ -80,10 +91,7 @@ impl<'a> Navigation<'a> {
             let mut without_docs_part = path.components();
             let _ = without_docs_part.next();
 
-            let link_path = link
-                    .path
-                    .strip_prefix(self.config.base_path())
-                    .unwrap();
+            let link_path = link.path.strip_prefix(self.config.base_path()).unwrap();
 
             let doc_path = Link::path_to_uri(without_docs_part.as_path());
 
@@ -177,7 +185,7 @@ mod test {
             Path::new(path),
             "Not important".to_string(),
             frontmatter,
-            base_path.unwrap_or("/")
+            base_path.unwrap_or("/"),
         )
     }
 
@@ -191,14 +199,14 @@ mod test {
     fn basic() {
         let config = config(None);
         let root = Directory {
-            path: PathBuf::from("docs"),
+            path: config.docs_dir().to_path_buf(),
             docs: vec![
                 page("README.md", "Getting Started", None),
                 page("one.md", "One", None),
                 page("two.md", "Two", None),
             ],
             dirs: vec![Directory {
-                path: PathBuf::from("docs").join("child"),
+                path: config.docs_dir().join("child"),
                 docs: vec![
                     page("child/README.md", "Nested Root", None),
                     page("child/three.md", "Three", None),
@@ -368,7 +376,7 @@ mod test {
 
         let config = config(None);
         let navigation = Navigation::new(&config);
-        let links: Vec<Link> = root.links();
+        let links: Vec<Link> = root.links(true);
 
         assert_eq!(
             navigation.customize(&rules, &links),
@@ -435,7 +443,7 @@ mod test {
 
         let config = config(None);
         let navigation = Navigation::new(&config);
-        let links: Vec<Link> = root.links();
+        let links: Vec<Link> = root.links(true);
 
         assert_eq!(
             navigation.customize(&rules, &links),
@@ -483,7 +491,7 @@ mod test {
 
         let config = config(None);
         let navigation = Navigation::new(&config);
-        let links: Vec<Link> = root.links();
+        let links: Vec<Link> = root.links(true);
 
         assert_eq!(
             navigation.customize(&rules, &links),
@@ -519,7 +527,7 @@ mod test {
 
         let config = config(None);
         let navigation = Navigation::new(&config);
-        let links: Vec<Link> = root.links();
+        let links: Vec<Link> = root.links(true);
 
         assert_eq!(
             navigation.customize(&rules, &links),
@@ -546,22 +554,14 @@ mod test {
         let root = Directory {
             path: PathBuf::from("docs"),
             docs: vec![
-                page(
-                    "README.md",
-                    "Getting Started",
-                    Some(config.base_path()),
-                ),
+                page("README.md", "Getting Started", Some(config.base_path())),
                 page("one.md", "One", Some(config.base_path())),
                 page("two.md", "Two", Some(config.base_path())),
             ],
             dirs: vec![Directory {
                 path: PathBuf::from("docs").join("child"),
                 docs: vec![
-                    page(
-                        "child/README.md",
-                        "Nested Root",
-                        Some(config.base_path()),
-                    ),
+                    page("child/README.md", "Nested Root", Some(config.base_path())),
                     page("child/three.md", "Three", Some(config.base_path())),
                 ],
                 dirs: vec![],
